==> kvision-maps-js-7.4.4-sources.jar: jsMain/io/kvision/maps/externals/leaflet/layer/vector/SVG.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

@file:JsModule("leaflet")
@file:JsNonModule

package io.kvision.maps.externals.leaflet.layer.vector

import io.kvision.maps.externals.leaflet.geometry.Point
import org.w3c.dom.svg.SVGElement

open external class SVG(
    options: RendererOptions = definedExternally
) : Renderer<Renderer.RendererOptions> {

    companion object {

        /** @param[name] The name of an [SVG element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element),
         * for example `line` or `circle` */
        fun create(name: String): SVGElement

        /**
         * Generates an SVG path string for multiple rings, with each ring turning into `M..L..L..`
         * instructions.
         */
        fun pointsToPath(
            rings: Array<Point>,
            closed: Boolean
        ): String
    }
}

==> kvision-maps-js-9.0.0-sources.jar: jsMain/io/kvision/maps/externals/leaflet/layer/vector/SVG.kt <==
/*
 * Copyright (c) 2017-present Robert Jaros
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

@file:JsModule("leaflet/dist/leaflet-src.esm.js")

package io.kvision.maps.externals.leaflet.layer.vector

import io.kvision.maps.externals.leaflet.geometry.Point
import org.w3c.dom.svg.SVGElement

open external class SVG(
    options: RendererOptions = definedExternally
) : Renderer<Renderer.RendererOptions> {

    companion object {

        /** @param[name] The name of an [SVG element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element),
         * for example `line` or `circle` */
        fun create(name: String): SVGElement

        /**
         * Generates an SVG path string for multiple rings, with each ring turning into `M..L..L..`
         * instructions.
         */
        fun pointsToPath(
            rings: Array<Point>,
            closed: Boolean
        ): String
    }
}
